@@ -39,6 +39,7 @@ __all__ = (
     "RetentionActionType",
     "UserRoleType",
     "ServiceName",
+    "PaginatorName",
 )
 
 
@@ -330,10 +331,12 @@ ServiceName = Literal[
     "transcribe",
     "transfer",
     "translate",
+    "voice-id",
     "waf",
     "waf-regional",
     "wafv2",
     "wellarchitected",
+    "wisdom",
     "workdocs",
     "worklink",
     "workmail",
@@ -341,3 +344,13 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+PaginatorName = Literal[
+    "list_aliases",
+    "list_group_members",
+    "list_groups",
+    "list_mailbox_permissions",
+    "list_organizations",
+    "list_resource_delegates",
+    "list_resources",
+    "list_users",
+]
